@@ -62,11 +62,11 @@ App::Dochazka::CLI::Commands::Employee - Employee commands
 
 =head1 VERSION
 
-Version 0.196
+Version 0.197
 
 =cut
 
-our $VERSION = '0.196';
+our $VERSION = '0.197';
 
 
 
@@ -114,6 +114,15 @@ sub employee_profile {
     return $status unless $status->ok;
     my $emp = $status->payload;
 
+    # determine supervisor
+    my $supervisor_nick;
+    if ( my $supervisor_eid = $emp->supervisor ) {
+        $status = determine_employee( "EMPL=$supervisor_eid" );
+        if ( $status->ok and $status->payload ) {
+            $supervisor_nick = $status->payload->nick;
+        }
+    }
+
     # GET priv/eid/:eid
     $status = send_req( 'GET', 'priv/eid/' . $emp->eid );
     return rest_error( $status, "Determine employee privlevel" ) unless $status->ok;
@@ -127,6 +136,7 @@ sub employee_profile {
     $message .= "Dochazka EID: " . $emp->eid . "\n";
     $message .= "Password*:    (" . ( $emp->passhash ? "set" : "not set" ) . ")\n";
     $message .= "Privlevel:    $priv\n";
+    $message .= "Reports to:   " . ( $supervisor_nick ? $supervisor_nick : "(not set)" ) . "\n";
     $message .= "\n";
     $message .= "* Internal password stored in the Dochazka database - \n";
     $message .= "  irrelevant if external authentication in use.\n";
